#!/usr/bin/env python3
# Copyright (C) 2025 Spearhead Systems SRL

import copy
from cmk.base.plugins.agent_based.agent_based_api.v1 import State
from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    HostRulespec,
    RulespecGroupCheckParametersNetworking,
    CheckParameterRulespecWithItem
)
from cmk.gui.watolib.rulespecs import Rulespec
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    ListOfStrings,
    Tuple,
    TextInput
)


def _valuespec_special_agents_domains_expiry_query():
    return Dictionary(
        title=_("Domains Expiry Query"),
        required_keys=["domains"],
        elements=[
            (
                "domains",
                ListOfStrings(
                    title=_("Domain names"),
                    help=_("List of domain names to check"),
                    allow_empty=False,
                ),
            ),
        ]
    )

def _valuespec_special_agents_domains_expiry_checks():
    return Dictionary(
        title=_("Domains Expiry"),
        required_keys=["days_remaining"],
        elements=[
             (
                "days_remaining",
                Tuple(
                    title=_("Days Remaining"),
                    help=_("If there are fewer days until one of the above domains expires, issue an alert"),
                    elements=[
                        Integer(
                            title=_("Warn if fewer days than"),
                            minvalue=0,
                            default_value=30
                        ),
                        Integer(
                            title=_("Crit if fewer days than"),
                            minvalue=0,
                            default_value=7
                        )
                    ]
                )
            ),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        name="special_agents:domains_expiry",
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        valuespec=_valuespec_special_agents_domains_expiry_query,
    )
)
rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="domains_expiry",
        group=RulespecGroupCheckParametersNetworking,
        match_type="dict",
        parameter_valuespec=_valuespec_special_agents_domains_expiry_checks,
        item_spec=lambda: TextInput(title=_("Expiry")),
        title=lambda: _("Domains Expiry Checks"),
    )
)
